isInitialized property
bool
get
isInitialized
Sets the current locale. Returns whether initialization has happened and the data is ready.
Implementation
// static void setLocale(Locale locale) {
// FlutterSExtensions.locale = locale;
// }
/// Returns whether initialization has happened and the data is ready.
static bool get isInitialized => _initialized && _media != null;